==> hhvm_3.2.0+dfsg1.orig.tar.xz: hhvm-3.2.0+dfsg/hphp/test/slow/ext_openssl/openssl_pkey_get_details_4.php <==
<?php

$key = <<<EOF
-----BEGIN DSA PRIVATE KEY-----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-----END DSA PRIVATE KEY-----
EOF;

$res = openssl_pkey_get_private($key);
var_dump(openssl_pkey_get_details($res));
?>

==> hhvm_3.21.0+dfsg.orig.tar.xz: hhvm-3.21.0+dfsg/hphp/test/slow/ext_openssl/openssl_pkey_get_details_4.php <==
<?php

$key = <<<EOF
-----BEGIN DSA PRIVATE KEY-----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-----END DSA PRIVATE KEY-----
EOF;

$res = openssl_pkey_get_private($key);
include __DIR__.'/recursive.inc';
var_dump(openssl_pkey_get_bin2hex_details($res));
?>
